@@ -1,22 +1,10 @@
 /*
-   Copyright (C) 2009 Andras Mantia <amantia@kde.org>
+   SPDX-FileCopyrightText: 2009 Andras Mantia <amantia@kde.org>
 
-   Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-   Author: Kevin Ottens <kevin@kdab.com>
+   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+   SPDX-FileContributor: Kevin Ottens <kevin@kdab.com>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <QTest>
@@ -55,6 +43,18 @@ private Q_SLOTS:
                  << "C: A000001 CREATE \"INBOX-FAIL-NO\""
                  << "S: A000001 NO create failure";
         QTest::newRow("no") << "INBOX-FAIL-NO" << scenario;
+
+        scenario.clear();
+        scenario << FakeServer::preauth()
+                 << "C: A000001 CREATE \"INBOX-FAIL-IGNOREDCODE\""
+                 << "S: A000001 NO create failure [IGNOREDCODE]";
+        QTest::newRow("ignoredcode") << "INBOX-FAIL-IGNOREDCODE" << scenario;
+
+        scenario.clear();
+        scenario << FakeServer::preauth()
+                 << "C: A000001 CREATE \"INBOX-ALREADYEXISTS\""
+                 << "S: A000001 NO create failure [ALREADYEXISTS]";
+        QTest::newRow("alreadyexists") << "INBOX-ALREADYEXISTS" << scenario;
     }
 
     void testCreate()
@@ -72,6 +72,7 @@ private Q_SLOTS:
         bool result = job->exec();
         QEXPECT_FAIL("bad" , "Expected failure on BAD response", Continue);
         QEXPECT_FAIL("no" , "Expected failure on NO response", Continue);
+        QEXPECT_FAIL("ignoredcode" , "Expected failure on NO response with ignored response code", Continue);
         QVERIFY(result);
         if (result) {
             QCOMPARE(job->mailBox(), mailbox);
